
#include "stdlib.h"      /* Standard Includes                                */
#include "stdio.h"
#include "addermfx.h"    /* MFX Data Structure "mfi" Definitions (P) by XBW  */
#include "xbmfx.c"       /* MFX read/write routines; contributed by XBW      */
#include "addermfx.c"    /* Get Read and Write MFX Routines; (P) by XbW      */
 
MFI mfi;                 /* Data Structure for Communication with XbW        */
 
main(){
  ReadMFXGroup_mfi(0,0);       /* Data Input Section                         */
  mfi.Display=1;               /* Data Processing:    activate object display*/
  switch(mfi.Cmd[0]){                              /* execute command        */
    case 'A' : mfi.Sum = mfi.A + mfi.B; break;     /* ADD                    */
    case 'S' : mfi.Sum = mfi.A - mfi.B; break;     /* SUB                    */
    default  : mfi.Display=0;                      /* object display OFF     */
    };
  WriteMFXGroup_mfi(0,0,0);    /* Data Output Section                        */
  };

 
 
